;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "quick-fasd" "20250915.131"
  "Integration for the command-line tool `fasd'."
  '((emacs "25.1"))
  :url "https://github.com/jamescherti/quick-fasd.el"
  :commit "fe0d6c611ec995e2f59b23d45af3b8b28244703b"
  :revdesc "fe0d6c611ec9"
  :keywords '("convenience"))
